import { NgZone, OnInit } from '@angular/core';
import { NgForm, NgModel } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';
import { BaseAuthData } from '../../models/base-auth-data.model';
import { BaseRole } from '../../models/base-role.model';
import { BaseToken } from '../../models/base-token.model';
import { ErrorData } from '../../models/error-data.model';
import { JwtAuthService } from '../../services/jwt-auth.service';
import * as i0 from "@angular/core";
/**
 * The interface for the confirm reset password functionality.
 *
 * !!!
 * Also checks if the provided reset token is valid.
 * This tries to get the reset token from theActivatedRoute.params['token'].
 * You have to make sure that your reset password link and the routing makes that possible.
 * !!!
 */
export declare class NgxMatAuthConfirmResetPasswordComponent<AuthDataType extends BaseAuthData<TokenType, RoleValue, Role>, TokenType extends BaseToken, RoleValue extends string, Role extends BaseRole<RoleValue>, AuthServiceType extends JwtAuthService<AuthDataType, RoleValue, Role, TokenType>> implements OnInit {
    protected readonly authService: AuthServiceType;
    protected readonly defaultGetValidationErrorMessage: (model: NgModel) => string;
    protected readonly router: Router;
    protected readonly route: ActivatedRoute;
    protected readonly zone: NgZone;
    protected readonly dialog: MatDialog;
    /**
     * (optional) A custom function to generate the error-message for invalid inputs.
     */
    getValidationErrorMessage: (model: NgModel) => string;
    /**
     * The title of the confirm reset password box.
     * @default 'New Password'
     */
    confirmResetPasswordTitle: string;
    /**
     * The label for the password input.
     * @default 'Password'
     */
    passwordInputLabel: string;
    /**
     * The minimum length for the password input.
     * @default null // no minimum length
     */
    minLength: number;
    /**
     * The label for the change password button.
     * @default 'Change Password'
     */
    changePasswordButtonLabel: string;
    /**
     * A custom label for the cancel button.
     * @default 'Cancel'
     */
    cancelButtonLabel: string;
    /**
     * The route to which the user gets redirected when he clicks on the cancel button.
     * @default routeAfterReset
     */
    routeForCancel: string;
    /**
     * The route to which the user gets redirected after the password has been changed successfully.
     * @default '/login'
     */
    routeAfterReset: string;
    /**
     * The route to which the user gets redirected if the reset token is not correct.
     * @default '/'
     */
    routeIfResetTokenInvalid: string;
    /**
     * The error data to display in an dialog when the provided reset token doesn't exist or is invalid.
     * @default
     *{
     * name: 'Error',
     * message: '<p>The provided link is no longer active.</p><p>Please check if the url is correct or request a new link.</p>'
     *}
     */
    invalidResetTokenErrorData: ErrorData;
    /**
     * The password input by the user.
     */
    password?: string;
    /**
     * Whether or not the password input is hidden.
     */
    hide: boolean;
    /**
     * Whether or not the confirm password input is hidden.
     */
    hideConfirm: boolean;
    private resetToken?;
    private readonly defaultInvalidResetTokenErrorData;
    constructor(authService: AuthServiceType, defaultGetValidationErrorMessage: (model: NgModel) => string, router: Router, route: ActivatedRoute, zone: NgZone, dialog: MatDialog);
    ngOnInit(): void;
    private initDefaultValues;
    /**
     * Cancels the password reset.
     */
    cancel(): Promise<void>;
    /**
     * Changes the password.
     * @param form - The form. Is passed to clear it without triggering input validation errors.
     */
    onSubmit(form: NgForm): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxMatAuthConfirmResetPasswordComponent<any, any, any, any, any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxMatAuthConfirmResetPasswordComponent<any, any, any, any, any>, "ngx-mat-auth-confirm-reset-password", never, { "getValidationErrorMessage": { "alias": "getValidationErrorMessage"; "required": false; }; "confirmResetPasswordTitle": { "alias": "confirmResetPasswordTitle"; "required": false; }; "passwordInputLabel": { "alias": "passwordInputLabel"; "required": false; }; "minLength": { "alias": "minLength"; "required": false; }; "changePasswordButtonLabel": { "alias": "changePasswordButtonLabel"; "required": false; }; "cancelButtonLabel": { "alias": "cancelButtonLabel"; "required": false; }; "routeForCancel": { "alias": "routeForCancel"; "required": false; }; "routeAfterReset": { "alias": "routeAfterReset"; "required": false; }; "routeIfResetTokenInvalid": { "alias": "routeIfResetTokenInvalid"; "required": false; }; "invalidResetTokenErrorData": { "alias": "invalidResetTokenErrorData"; "required": false; }; }, {}, never, never, true, never>;
}
