import { OnInit } from '@angular/core';
import { NgForm, NgModel } from '@angular/forms';
import { Router } from '@angular/router';
import { BaseAuthData } from '../../models/base-auth-data.model';
import { BaseRole } from '../../models/base-role.model';
import { BaseToken } from '../../models/base-token.model';
import { JwtAuthService } from '../../services/jwt-auth.service';
import * as i0 from "@angular/core";
/**
 * The data for the forgot password link in the login component.
 */
export interface ForgotPasswordLinkData {
    /**
     * What is displayed in the UI.
     * @default 'Forgot your password?'
     */
    displayName: string;
    /**
     * The route to which the link navigates.
     * @default '/reset-password'
     */
    route: string;
}
/**
 * A simple login box.
 */
export declare class NgxMatAuthLoginComponent<AuthDataType extends BaseAuthData<TokenType, RoleValue, Role>, TokenType extends BaseToken, RoleValue extends string, Role extends BaseRole<RoleValue>, AuthServiceType extends JwtAuthService<AuthDataType, RoleValue, Role, TokenType>> implements OnInit {
    protected readonly authService: AuthServiceType;
    protected readonly defaultGetValidationErrorMessage: (model: NgModel) => string;
    protected readonly router: Router;
    /**
     * (optional) A custom function to generate the error-message for invalid inputs.
     */
    getValidationErrorMessage: (model: NgModel) => string;
    /**
     * A custom title of the login box.
     * @default 'Login'
     */
    loginTitle: string;
    /**
     * A custom label for the email input.
     * @default 'Email'
     */
    emailInputLabel: string;
    /**
     * A custom label for the password input.
     * @default 'Password'
     */
    passwordInputLabel: string;
    /**
     * A custom label for the login button.
     * @default 'Login'
     */
    loginButtonLabel: string;
    /**
     * Data for the forgot password link.
     * @default {
     * displayName: 'Forgot your password?',
     * route: '/reset-password'
     * }
     */
    forgotPasswordLinkData: ForgotPasswordLinkData;
    /**
     * The route to which the user gets redirected after he logs in successful.
     * @default '/'
     */
    routeAfterLogin: string;
    /**
     * Whether or not the user should be prompted for biometric login if the option is available.
     * @default true
     */
    automaticallyPromptForBiometricLogin: boolean;
    /**
     * The password input by the user.
     */
    password?: string;
    /**
     * The email input by the user.
     */
    email?: string;
    /**
     * Whether or not the password input is hidden.
     */
    hide: boolean;
    constructor(authService: AuthServiceType, defaultGetValidationErrorMessage: (model: NgModel) => string, router: Router);
    ngOnInit(): void;
    /**
     * The method that gets called when the user tries to login.
     * @param form - The login form. Is passed to clear it without triggering input validation errors.
     */
    onSubmit(form: NgForm): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxMatAuthLoginComponent<any, any, any, any, any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxMatAuthLoginComponent<any, any, any, any, any>, "ngx-mat-auth-login", never, { "getValidationErrorMessage": { "alias": "getValidationErrorMessage"; "required": false; }; "loginTitle": { "alias": "loginTitle"; "required": false; }; "emailInputLabel": { "alias": "emailInputLabel"; "required": false; }; "passwordInputLabel": { "alias": "passwordInputLabel"; "required": false; }; "loginButtonLabel": { "alias": "loginButtonLabel"; "required": false; }; "forgotPasswordLinkData": { "alias": "forgotPasswordLinkData"; "required": false; }; "routeAfterLogin": { "alias": "routeAfterLogin"; "required": false; }; "automaticallyPromptForBiometricLogin": { "alias": "automaticallyPromptForBiometricLogin"; "required": false; }; }, {}, never, never, true, never>;
}
