import { OnInit } from '@angular/core';
import { NgForm, NgModel } from '@angular/forms';
import { Router } from '@angular/router';
import { BaseAuthData } from '../../models/base-auth-data.model';
import { BaseRole } from '../../models/base-role.model';
import { BaseToken } from '../../models/base-token.model';
import { JwtAuthService } from '../../services/jwt-auth.service';
import * as i0 from "@angular/core";
/**
 * A simple request reset password box.
 */
export declare class NgxMatAuthRequestResetPasswordComponent<AuthDataType extends BaseAuthData<TokenType, RoleValue, Role>, TokenType extends BaseToken, RoleValue extends string, Role extends BaseRole<RoleValue>, AuthServiceType extends JwtAuthService<AuthDataType, RoleValue, Role, TokenType>> implements OnInit {
    protected readonly authService: AuthServiceType;
    protected readonly defaultGetValidationErrorMessage: (model: NgModel) => string;
    protected readonly router: Router;
    /**
     * (optional) A custom function to generate the error-message for invalid inputs.
     */
    getValidationErrorMessage: (model: NgModel) => string;
    /**
     * The title of the request reset password box.
     * @default 'Forgot Password'
     */
    requestResetPasswordTitle: string;
    /**
     * A custom label for the email input.
     * @default 'Email'
     */
    emailInputLabel: string;
    /**
     * A custom label for the send email button.
     * @default 'Send Email'
     */
    sendEmailButtonLabel: string;
    /**
     * A custom label for the cancel button.
     * @default 'Cancel'
     */
    cancelButtonLabel: string;
    /**
     * The route to navigate to after the user successfully requests the reset of his password.
     * @default '/login'
     */
    routeAfterRequest: string;
    /**
     * The email for the account which password should be reset.
     */
    email?: string;
    constructor(authService: AuthServiceType, defaultGetValidationErrorMessage: (model: NgModel) => string, router: Router);
    ngOnInit(): void;
    /**
     * Cancels the password reset.
     */
    cancel(): Promise<void>;
    /**
     * Requests the reset of the password for the user with the given email.
     * @param form - The login form. Is passed to clear it without triggering input validation errors.
     */
    onSubmit(form: NgForm): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxMatAuthRequestResetPasswordComponent<any, any, any, any, any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxMatAuthRequestResetPasswordComponent<any, any, any, any, any>, "ngx-mat-auth-request-reset-password", never, { "getValidationErrorMessage": { "alias": "getValidationErrorMessage"; "required": false; }; "requestResetPasswordTitle": { "alias": "requestResetPasswordTitle"; "required": false; }; "emailInputLabel": { "alias": "emailInputLabel"; "required": false; }; "sendEmailButtonLabel": { "alias": "sendEmailButtonLabel"; "required": false; }; "cancelButtonLabel": { "alias": "cancelButtonLabel"; "required": false; }; "routeAfterRequest": { "alias": "routeAfterRequest"; "required": false; }; }, {}, never, never, true, never>;
}
