import { ElementRef, EventEmitter, QueryList } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * The value a step index might have. Ranges from 0 - 5.
 */
type StepIndex = 0 | 1 | 2 | 3 | 4 | 5;
/**
 * The value that can be set to a step input.
 */
type StepValue = '' | '0' | '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9';
/**
 * A component that displays an input for a 6 digit numeric two factor code.
 * You can receive the code by listening to the "codeChangeEvent".
 */
export declare class NgxMatAuthTwoFactorCodeInputComponent {
    readonly steps: [StepValue, StepValue, StepValue, StepValue, StepValue, StepValue];
    /**
     * The two factor input html elements.
     */
    stepElements: QueryList<ElementRef>;
    /**
     * Returns the code whenever the user inputs or removes something.
     */
    readonly codeChangeEvent: EventEmitter<string>;
    private readonly keyCodesToIgnore;
    /**
     * When the user uses the backspace, the previous input is selected (if it exists).
     * When he types anything else, the next input is selected (if it exists).
     * @param event - The keyboard event contains eg. The key that was pressed.
     * @param stepIndex - At which step the input happened.
     */
    keyup(event: KeyboardEvent, stepIndex: StepIndex): void;
    /**
     * Sets all code inputs to the first six digits provided by the pasted content.
     * @param event - The clipboard event with all relevant information.
     */
    paste(event: ClipboardEvent): void;
    /**
     * Automatically moves the cursor to the correct input.
     * If eg. The first value hasn't been provided yet the user can't click on the input for the last value.
     * @param stepIndex - The step index that the user tries to focus.
     */
    focused(stepIndex: StepIndex): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxMatAuthTwoFactorCodeInputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxMatAuthTwoFactorCodeInputComponent, "ngx-mat-auth-two-factor-code-input", never, {}, { "codeChangeEvent": "codeChangeEvent"; }, never, never, true, never>;
}
export {};
