import { NgIf, NgFor, isPlatformBrowser } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, Inject, EventEmitter, ViewChildren, Output, InjectionToken, PLATFORM_ID, Input, inject, Injectable } from '@angular/core';
import * as i2$1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i2 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i3 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i4 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import { BehaviorSubject, firstValueFrom, filter, catchError, throwError, from, exhaustMap } from 'rxjs';
import { __decorate, __param } from 'tslib';
import * as i1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { toCanvas } from 'qrcode';
import { startRegistration, startAuthentication, browserSupportsWebAuthn } from '@simplewebauthn/browser';
import * as i1$1 from '@angular/router';
import { RouterModule, Router } from '@angular/router';
import { HttpStatusCode } from '@angular/common/http';

/**
 * A generic Error Dialog that displays ErrorData.
 */
class NgxMatAuthErrorDialogComponent {
    dialogRef;
    error;
    constructor(dialogRef, error) {
        this.dialogRef = dialogRef;
        this.error = error;
    }
    /**
     * Closes the dialog.
     */
    close() {
        this.dialogRef.close();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthErrorDialogComponent, deps: [{ token: i1.MatDialogRef }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: NgxMatAuthErrorDialogComponent, isStandalone: true, selector: "ngx-material-auth-error-dialog", ngImport: i0, template: "<h1 mat-dialog-title>{{error.name}}</h1>\n<mat-dialog-content>\n    <div class=\"error-message\" mat-dialog-content [innerHtml]=\"error.message\">\n    </div>\n</mat-dialog-content>\n\n<mat-dialog-actions class=\"dialog-actions\">\n    <button type=\"button\" mat-raised-button (click)=\"close()\">Ok</button>\n</mat-dialog-actions>", styles: [".error-message{padding:0}.dialog-actions{display:flex;justify-content:center}\n"], dependencies: [{ kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthErrorDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-material-auth-error-dialog', standalone: true, imports: [
                        MatButtonModule,
                        MatDialogModule
                    ], template: "<h1 mat-dialog-title>{{error.name}}</h1>\n<mat-dialog-content>\n    <div class=\"error-message\" mat-dialog-content [innerHtml]=\"error.message\">\n    </div>\n</mat-dialog-content>\n\n<mat-dialog-actions class=\"dialog-actions\">\n    <button type=\"button\" mat-raised-button (click)=\"close()\">Ok</button>\n</mat-dialog-actions>", styles: [".error-message{padding:0}.dialog-actions{display:flex;justify-content:center}\n"] }]
        }], ctorParameters: () => [{ type: i1.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }] });

const allowedValues = ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'];
/**
 * A component that displays an input for a 6 digit numeric two factor code.
 * You can receive the code by listening to the "codeChangeEvent".
 */
class NgxMatAuthTwoFactorCodeInputComponent {
    // eslint-disable-next-line jsdoc/require-jsdoc
    steps = ['', '', '', '', '', ''];
    /**
     * The two factor input html elements.
     */
    stepElements;
    /**
     * Returns the code whenever the user inputs or removes something.
     */
    codeChangeEvent = new EventEmitter();
    keyCodesToIgnore = [
        'ArrowUp',
        'ArrowDown',
        'ArrowLeft',
        'ArrowRight'
    ];
    /**
     * When the user uses the backspace, the previous input is selected (if it exists).
     * When he types anything else, the next input is selected (if it exists).
     * @param event - The keyboard event contains eg. The key that was pressed.
     * @param stepIndex - At which step the input happened.
     */
    keyup(event, stepIndex) {
        if (this.keyCodesToIgnore.includes(event.key)) {
            return;
        }
        const prevElement = this.stepElements.toArray()[stepIndex - 1];
        const nextElement = this.stepElements.toArray()[stepIndex + 1];
        if (event.code === 'Backspace' && prevElement) {
            this.steps[stepIndex - 1] = '';
            prevElement.nativeElement.focus();
            const value = this.steps.join('');
            this.codeChangeEvent.emit(value);
            return;
        }
        if (nextElement) {
            if (allowedValues.includes(event.key)) {
                this.steps[stepIndex] = event.key;
            }
            const value = this.steps.join('');
            this.codeChangeEvent.emit(value);
            nextElement.nativeElement.focus();
        }
    }
    /**
     * Sets all code inputs to the first six digits provided by the pasted content.
     * @param event - The clipboard event with all relevant information.
     */
    paste(event) {
        const clipboardData = event.clipboardData;
        const pastedText = clipboardData.getData('text');
        for (const char of pastedText) {
            if (!allowedValues.includes(char)) {
                return;
            }
        }
        for (let i = 0; i < this.steps.length; i++) {
            this.steps[i] = pastedText.charAt(i);
        }
        const value = this.steps.join('');
        this.codeChangeEvent.emit(value);
    }
    /**
     * Automatically moves the cursor to the correct input.
     * If eg. The first value hasn't been provided yet the user can't click on the input for the last value.
     * @param stepIndex - The step index that the user tries to focus.
     */
    focused(stepIndex) {
        const firstEmptyInputIndex = this.steps.findIndex(s => !s);
        if (stepIndex === firstEmptyInputIndex) {
            return;
        }
        if (firstEmptyInputIndex === -1) {
            this.stepElements.toArray()[5].nativeElement.focus();
        }
        this.stepElements.toArray()[firstEmptyInputIndex].nativeElement.focus();
        // let firstEmptyInputIndex: number | undefined = undefined;
        // for (let i: number = 0; i < this.steps.length; i++) {
        //     // The first time an empty input is reached
        //     if (!this.steps[i] && firstEmptyInputIndex == undefined) {
        //         if (stepIndex === i) {
        //             // the cursor is at the correct input already, nothing needs to be done
        //             return;
        //         }
        //         firstEmptyInputIndex = i;
        //     }
        //     // If an input with a value is reached after an empty input.
        //     if (this.steps[i] && firstEmptyInputIndex != undefined) {
        //         this.steps[i] = '';
        //     }
        // }
        // firstEmptyInputIndex = firstEmptyInputIndex ?? 5;
        // (this.stepElements.toArray()[firstEmptyInputIndex] as ElementRef<HTMLElement>).nativeElement.focus();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthTwoFactorCodeInputComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: NgxMatAuthTwoFactorCodeInputComponent, isStandalone: true, selector: "ngx-mat-auth-two-factor-code-input", outputs: { codeChangeEvent: "codeChangeEvent" }, viewQueries: [{ propertyName: "stepElements", predicate: ["code1,code2,code3,code4,code5,code6"], descendants: true }], ngImport: i0, template: "<div class=\"code-container\">\n    <input #code1\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[0]\"\n        [(ngModel)]=\"steps[0]\"\n        (keyup)=\"keyup($event, 0)\"\n        (focus)=\"focused(0)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code2\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[1]\"\n        [(ngModel)]=\"steps[1]\"\n        (keyup)=\"keyup($event, 1)\"\n        (focus)=\"focused(1)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code3\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[2]\"\n        [(ngModel)]=\"steps[2]\"\n        (keyup)=\"keyup($event, 2)\"\n        (focus)=\"focused(2)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code4\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[3]\"\n        [(ngModel)]=\"steps[3]\"\n        (keyup)=\"keyup($event, 3)\"\n        (focus)=\"focused(3)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code5\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[4]\"\n        [(ngModel)]=\"steps[4]\"\n        (keyup)=\"keyup($event, 4)\"\n        (focus)=\"focused(4)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code6\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[5]\"\n        [(ngModel)]=\"steps[5]\"\n        (keyup)=\"keyup($event, 5)\"\n        (focus)=\"focused(5)\"\n        (paste)=\"paste($event)\"\n    >\n</div>", styles: ["input{caret-color:#0009;flex:1 1 0px;width:0;border:2px solid rgba(0,0,0,.6);border-radius:5px;text-align:center;padding:5px;background-color:#f5f5f5}input:focus{outline:2px solid rgba(0,128,0,.6);border-color:#00800099}.code-container{display:flex;width:100%;gap:10px}.valid{border:2px solid rgba(0,128,0,.6)}\n"], dependencies: [{ kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i4.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.MinLengthValidator, selector: "[minlength][formControlName],[minlength][formControl],[minlength][ngModel]", inputs: ["minlength"] }, { kind: "directive", type: i2$1.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i2$1.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthTwoFactorCodeInputComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-auth-two-factor-code-input', standalone: true, imports: [
                        MatInputModule,
                        FormsModule
                    ], template: "<div class=\"code-container\">\n    <input #code1\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[0]\"\n        [(ngModel)]=\"steps[0]\"\n        (keyup)=\"keyup($event, 0)\"\n        (focus)=\"focused(0)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code2\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[1]\"\n        [(ngModel)]=\"steps[1]\"\n        (keyup)=\"keyup($event, 1)\"\n        (focus)=\"focused(1)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code3\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[2]\"\n        [(ngModel)]=\"steps[2]\"\n        (keyup)=\"keyup($event, 2)\"\n        (focus)=\"focused(2)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code4\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[3]\"\n        [(ngModel)]=\"steps[3]\"\n        (keyup)=\"keyup($event, 3)\"\n        (focus)=\"focused(3)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code5\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[4]\"\n        [(ngModel)]=\"steps[4]\"\n        (keyup)=\"keyup($event, 4)\"\n        (focus)=\"focused(4)\"\n        (paste)=\"paste($event)\"\n    >\n    <input #code6\n        matInput\n        minlength=\"1\"\n        maxlength=\"1\"\n        pattern=\"[0-9]\"\n        oninput=\"validity.valid || (value='');\"\n        [class.valid]=\"steps[5]\"\n        [(ngModel)]=\"steps[5]\"\n        (keyup)=\"keyup($event, 5)\"\n        (focus)=\"focused(5)\"\n        (paste)=\"paste($event)\"\n    >\n</div>", styles: ["input{caret-color:#0009;flex:1 1 0px;width:0;border:2px solid rgba(0,0,0,.6);border-radius:5px;text-align:center;padding:5px;background-color:#f5f5f5}input:focus{outline:2px solid rgba(0,128,0,.6);border-color:#00800099}.code-container{display:flex;width:100%;gap:10px}.valid{border:2px solid rgba(0,128,0,.6)}\n"] }]
        }], propDecorators: { stepElements: [{
                type: ViewChildren,
                args: ['code1,code2,code3,code4,code5,code6']
            }], codeChangeEvent: [{
                type: Output
            }] } });

/**
 * The dialog to setup two factor authentication.
 */
class NgxMatAuthSetupTwoFactorDialogComponent {
    authService;
    dialogRef;
    inputData;
    /**
     * The secret for generating totp's.
     */
    secret;
    /**
     * Configuration data for the dialog.
     */
    data;
    /**
     * The verification code model used in forms.
     */
    verificationCode = '';
    constructor(authService, dialogRef, inputData) {
        this.authService = authService;
        this.dialogRef = dialogRef;
        this.inputData = inputData;
        this.dialogRef.disableClose = true;
    }
    ngOnInit() {
        this.data = {
            title: this.inputData?.title ?? 'Two-Factor Authentication',
            description: this.inputData?.description ?? [
                'To enable two-factor authentication you can scan the QR Code',
                'with your authenticator app and enter the verification code below.',
                'Alternatively you can manually add the secret key.'
            ],
            secretLabel: this.inputData?.secretLabel ?? 'Secret',
            verificationCodeLabel: this.inputData?.verificationCodeLabel ?? 'Verification Code',
            cancelButtonLabel: this.inputData?.cancelButtonLabel ?? 'Cancel',
            confirmButtonLabel: this.inputData?.confirmButtonLabel ?? 'Activate'
        };
        // eslint-disable-next-line promise/prefer-await-to-then
        void this.authService.turnOn2FA().then(async (response) => {
            const canvas = document.getElementById('2fa-canvas');
            await toCanvas(canvas, response.url, {
                width: 180,
                margin: 0
            });
            this.secret = this.getSecretFromCode(response.url);
        });
    }
    getSecretFromCode(qrCode) {
        const queryString = qrCode.split('?')[1];
        const urlParams = new URLSearchParams(queryString);
        return urlParams.get('secret') ?? 'No secret could be found in the given url.';
    }
    /**
     * Confirms setting upt 2fa and then closes the dialog with true.
     */
    async confirm() {
        await this.authService.confirmTurnOn2FA(this.verificationCode);
        this.dialogRef.close(true);
    }
    /**
     * Closes the dialog with false.
     */
    cancel() {
        this.dialogRef.close(false);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthSetupTwoFactorDialogComponent, deps: [{ token: NGX_AUTH_SERVICE }, { token: i1.MatDialogRef }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: NgxMatAuthSetupTwoFactorDialogComponent, isStandalone: true, selector: "ngx-mat-auth-setup-two-factor-dialog", ngImport: i0, template: "<b mat-dialog-title>{{data.title}}</b>\n\n<mat-dialog-content>\n    @for (paragraph of data.description; track $index) {\n        <p>{{paragraph}}</p>\n    }\n\n    <!-- QR Code //TODO -->\n    <div class=\"qr-container\">\n        <canvas id=\"2fa-canvas\">\n        </canvas>\n    </div>\n\n    <div class=\"secret-container\">\n        <b>{{data.secretLabel}}: </b>\n        <br>\n        {{secret}}\n    </div>\n\n    <!-- Verification Code //TODO -->\n    <b>{{data.verificationCodeLabel}}</b>\n    <ngx-mat-auth-two-factor-code-input (codeChangeEvent)=\"verificationCode = $event\"></ngx-mat-auth-two-factor-code-input>\n\n    <div class=\"dialog-actions\">\n        <button class=\"confirm-button\" type=\"button\" mat-raised-button [disabled]=\"verificationCode.length !== 6\" (click)=\"confirm()\">{{data.confirmButtonLabel}}</button>\n        <button class=\"cancel-button\" type=\"button\" mat-raised-button (click)=\"cancel()\">{{data.cancelButtonLabel}}</button>\n    </div>\n</mat-dialog-content>", styles: [".dialog-actions{margin-top:15px;display:flex;justify-content:space-between}p{margin-bottom:0}.qr-container{text-align:center;margin-top:16px;margin-bottom:16px}.secret-container{margin-bottom:16px}\n"], dependencies: [{ kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "component", type: NgxMatAuthTwoFactorCodeInputComponent, selector: "ngx-mat-auth-two-factor-code-input", outputs: ["codeChangeEvent"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthSetupTwoFactorDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-auth-setup-two-factor-dialog', standalone: true, imports: [
                        NgIf,
                        NgFor,
                        MatDialogModule,
                        MatButtonModule,
                        NgxMatAuthTwoFactorCodeInputComponent
                    ], template: "<b mat-dialog-title>{{data.title}}</b>\n\n<mat-dialog-content>\n    @for (paragraph of data.description; track $index) {\n        <p>{{paragraph}}</p>\n    }\n\n    <!-- QR Code //TODO -->\n    <div class=\"qr-container\">\n        <canvas id=\"2fa-canvas\">\n        </canvas>\n    </div>\n\n    <div class=\"secret-container\">\n        <b>{{data.secretLabel}}: </b>\n        <br>\n        {{secret}}\n    </div>\n\n    <!-- Verification Code //TODO -->\n    <b>{{data.verificationCodeLabel}}</b>\n    <ngx-mat-auth-two-factor-code-input (codeChangeEvent)=\"verificationCode = $event\"></ngx-mat-auth-two-factor-code-input>\n\n    <div class=\"dialog-actions\">\n        <button class=\"confirm-button\" type=\"button\" mat-raised-button [disabled]=\"verificationCode.length !== 6\" (click)=\"confirm()\">{{data.confirmButtonLabel}}</button>\n        <button class=\"cancel-button\" type=\"button\" mat-raised-button (click)=\"cancel()\">{{data.cancelButtonLabel}}</button>\n    </div>\n</mat-dialog-content>", styles: [".dialog-actions{margin-top:15px;display:flex;justify-content:space-between}p{margin-bottom:0}.qr-container{text-align:center;margin-top:16px;margin-bottom:16px}.secret-container{margin-bottom:16px}\n"] }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }, { type: i1.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }] });

/**
 * A dialog to input a two factor code.
 */
class NgxMatAuthTwoFactorDialogComponent {
    dialogRef;
    inputData;
    /**
     * The code value. Gets updated as the user types.
     */
    code = '';
    /**
     * The Configuration for title, labels etc.
     */
    data;
    constructor(dialogRef, inputData) {
        this.dialogRef = dialogRef;
        this.inputData = inputData;
    }
    ngOnInit() {
        this.data = {
            title: this.inputData?.title ?? 'Two-Factor Authentication',
            description: this.inputData?.description ?? ['Enter the 6-digit code from your authenticator app'],
            cancelButtonLabel: this.inputData?.cancelButtonLabel ?? 'Cancel',
            confirmButtonLabel: this.inputData?.confirmButtonLabel ?? 'Confirm'
        };
    }
    /**
     * Closes the dialog with the input code.
     */
    confirm() {
        this.dialogRef.close(this.code);
    }
    /**
     * Closes the dialog.
     */
    cancel() {
        this.dialogRef.close();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthTwoFactorDialogComponent, deps: [{ token: i1.MatDialogRef }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: NgxMatAuthTwoFactorDialogComponent, isStandalone: true, selector: "ngx-mat-auth-two-factor-dialog", ngImport: i0, template: "<b mat-dialog-title>{{data.title}}</b>\n\n<mat-dialog-content>\n    @for (paragraph of data.description; track $index) {\n        <p>{{paragraph}}</p>\n    }\n\n    <ngx-mat-auth-two-factor-code-input (codeChangeEvent)=\"code = $event\"></ngx-mat-auth-two-factor-code-input>\n\n    <div class=\"dialog-actions\">\n        <button class=\"confirm-button\" type=\"button\" mat-raised-button [disabled]=\"code.length !== 6\" (click)=\"confirm()\">{{data.confirmButtonLabel}}</button>\n        <button class=\"cancel-button\" type=\"button\" mat-raised-button (click)=\"cancel()\">{{data.cancelButtonLabel}}</button>\n    </div>\n</mat-dialog-content>", styles: [".dialog-actions{margin-top:16px;display:flex;justify-content:space-between}\n"], dependencies: [{ kind: "component", type: NgxMatAuthTwoFactorCodeInputComponent, selector: "ngx-mat-auth-two-factor-code-input", outputs: ["codeChangeEvent"] }, { kind: "ngmodule", type: MatDialogModule }, { kind: "directive", type: i1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthTwoFactorDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-auth-two-factor-dialog', standalone: true, imports: [
                        NgFor,
                        NgxMatAuthTwoFactorCodeInputComponent,
                        MatDialogModule,
                        MatButtonModule
                    ], template: "<b mat-dialog-title>{{data.title}}</b>\n\n<mat-dialog-content>\n    @for (paragraph of data.description; track $index) {\n        <p>{{paragraph}}</p>\n    }\n\n    <ngx-mat-auth-two-factor-code-input (codeChangeEvent)=\"code = $event\"></ngx-mat-auth-two-factor-code-input>\n\n    <div class=\"dialog-actions\">\n        <button class=\"confirm-button\" type=\"button\" mat-raised-button [disabled]=\"code.length !== 6\" (click)=\"confirm()\">{{data.confirmButtonLabel}}</button>\n        <button class=\"cancel-button\" type=\"button\" mat-raised-button (click)=\"cancel()\">{{data.cancelButtonLabel}}</button>\n    </div>\n</mat-dialog-content>", styles: [".dialog-actions{margin-top:16px;display:flex;justify-content:space-between}\n"] }]
        }], ctorParameters: () => [{ type: i1.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }] });

/**
 * Encapsulates functionality of the '@simplewebauthn' package.
 */
class WebauthnUtilities {
    /**
     * Starts the registration of a new biometric credential.
     * @param options - Options for generating the credential, including a challenge and domain of the RP (relaying party).
     * @returns The confirmed registration that needs to be sent to the backend.
     */
    static async startRegistration(options) {
        return startRegistration(options);
    }
    /**
     * Starts the login process with the provided credential options.
     * @param options - The options, which could include a list of possible biometric logins.
     * @param useBrowserAutofill - Whether or not to use browser autofill.
     * @returns The resolved or rejected biometric login.
     */
    static async startAuthentication(options, useBrowserAutofill) {
        return startAuthentication(options, useBrowserAutofill);
    }
    /**
     * Whether or not the browser actually supports webauthn.
     * @returns True if the browser supports it, false otherwise.
     */
    static browserSupportsWebAuthn() {
        return browserSupportsWebAuthn();
    }
}

/**
 * Injection Token for the auth service.
 */
// eslint-disable-next-line typescript/no-explicit-any
const NGX_AUTH_SERVICE = new InjectionToken('Provider for the authService used eg. in guards or the login component.', {
    providedIn: 'root',
    factory: (() => {
        // eslint-disable-next-line no-console
        console.error(
        // eslint-disable-next-line stylistic/max-len
        'No AuthService has been provided for the token NGX_AUTH_SERVICE\nAdd this to your app.module.ts provider array:\n{\n    provide: NGX_AUTH_SERVICE,\n    useExisting: MyAuthService\n}');
        // eslint-disable-next-line typescript/no-explicit-any
    })
});
const ONE_HUNDRED_DAYS_IN_MS = 8640000000;
const HOUR_IN_MS = 3600000;
/**
 * The base class for an authentication service.
 */
let JwtAuthService = class JwtAuthService {
    http;
    snackbar;
    zone;
    router;
    dialog;
    platformId;
    /**
     * The subject of the currently stored authData.
     */
    authDataSubject;
    /**
     * Subject to check if the access token is currently being refreshed.
     */
    isRefreshingSubject = new BehaviorSubject(false);
    /**
     * The key for the authData saved in local storage.
     */
    AUTH_DATA_KEY = 'authData';
    /**
     * The key for the biometricCredentials saved in local storage.
     */
    BIOMETRIC_CREDENTIALS_KEY = 'biometricCredentials';
    /**
     * The duration of the access token in milliseconds.
     * @default 3600000 // 1 hour
     */
    ACCESS_TOKEN_DURATION_IN_MS = HOUR_IN_MS;
    /**
     * The duration of the refresh token in milliseconds.
     * @default 8640000000 // 100 days
     */
    REFRESH_TOKEN_DURATION_IN_MS = ONE_HUNDRED_DAYS_IN_MS;
    /**
     * The route for requesting a password change.
     * @default '/request-reset-password'
     */
    REQUEST_RESET_PASSWORD_ROUTE = '/request-reset-password';
    /**
     * The message to display inside a snackbar when the mail for resetting a password was sent successfully.
     * @default 'A Mail for changing your password is on its way'
     */
    REQUEST_RESET_PASSWORD_SNACK_BAR_MESSAGE = 'A Mail for changing your password is on its way';
    /**
     * The message to display inside a snackbar when password was reset successfully.
     * @default 'Password changed successfully!'
     */
    CONFIRM_RESET_PASSWORD_SNACK_BAR_MESSAGE = 'Password changed successfully!';
    /**
     * The name of the custom header that is used to transport two factor codes.
     * @default 'X-Authorization-2FA'
     */
    TWO_FACTOR_HEADER = 'X-Authorization-2FA';
    /**
     * When the user tries to access a route for which he doesn't have the permission and is logged out
     * he gets redirected to this route afterwards.
     * @default '/login'
     */
    ROUTE_AFTER_LOGOUT = '/login';
    // eslint-disable-next-line jsdoc/require-returns
    /**
     * The currently stored authData value.
     * Contains at least the token.
     */
    get authData() {
        return this.authDataSubject.value;
    }
    set authData(value) {
        if (!isPlatformBrowser(this.platformId)) {
            return;
        }
        value = this.transformAuthDataBeforeSetting(value);
        localStorage.setItem(this.AUTH_DATA_KEY, JSON.stringify(value));
        if (!value) {
            localStorage.removeItem(this.AUTH_DATA_KEY);
        }
        if (value?.biometricCredentials?.length) {
            this.biometricCredentials = value.biometricCredentials;
        }
        this.authDataSubject.next(value);
    }
    // eslint-disable-next-line jsdoc/require-returns
    /**
     * The biometricCredentials saved in local storage.
     * This is separated from the auth data because it's also needed when the user is logged out.
     */
    get biometricCredentials() {
        if (!isPlatformBrowser(this.platformId)) {
            return [];
        }
        const jsonString = localStorage.getItem(this.BIOMETRIC_CREDENTIALS_KEY);
        if (!jsonString) {
            return [];
        }
        return JSON.parse(jsonString);
    }
    set biometricCredentials(value) {
        if (!isPlatformBrowser(this.platformId)) {
            return;
        }
        localStorage.setItem(this.BIOMETRIC_CREDENTIALS_KEY, JSON.stringify(value));
        if (!value) {
            localStorage.removeItem(this.BIOMETRIC_CREDENTIALS_KEY);
        }
    }
    // eslint-disable-next-line jsdoc/require-returns
    /**
     * Whether or not the access token is currently being refreshed.
     */
    get isRefreshing() {
        return this.isRefreshingSubject.value;
    }
    constructor(http, snackbar, zone, router, dialog, platformId) {
        this.http = http;
        this.snackbar = snackbar;
        this.zone = zone;
        this.router = router;
        this.dialog = dialog;
        this.platformId = platformId;
        if (!isPlatformBrowser(platformId)) {
            this.authDataSubject = new BehaviorSubject(undefined);
            return;
        }
        const stringData = localStorage.getItem(this.AUTH_DATA_KEY);
        const authData = stringData ? JSON.parse(stringData) : undefined;
        this.authDataSubject = new BehaviorSubject(authData);
    }
    /**
     * Gets called right before auth data is set.
     * Can be used to transform some of the data.
     *
     * DEFAULT: When the api sends roles as a list of strings instead of Role objects,
     * they are transformed to role objects with displayName and value being the string send by the api.
     * @param authData - The auth data that should be set.
     * @returns The transformed auth data or undefined.
     */
    transformAuthDataBeforeSetting(authData) {
        if (!authData) {
            return undefined;
        }
        if (typeof authData.roles[0] === 'string') {
            authData.roles = authData.roles.map(r => {
                return {
                    displayName: r,
                    value: r
                };
            });
        }
        return authData;
    }
    /**
     * Login a user.
     * @param loginData - The data that is sent to the server to login the user.
     * @returns A promise of the received authData.
     */
    async login(loginData) {
        const res = await firstValueFrom(this.http.post(this.API_LOGIN_URL, loginData));
        if (this.isAuthDataType(res)) {
            this.authData = res;
            return this.authData;
        }
        if (this.isRequirePasswordChangeType(res)) {
            await this.openChangePasswordDialog();
            await this.router.navigateByUrl(this.REQUEST_RESET_PASSWORD_ROUTE);
            throw new Error('You are required to reset your password.');
        }
        const code = await this.openInput2FADialog();
        if (!code) {
            throw new Error('No two factor code has been provided.');
        }
        this.authData = await firstValueFrom(this.http.post(this.API_LOGIN_URL, loginData, { headers: { [this.TWO_FACTOR_HEADER]: code } }));
        return this.authData;
    }
    async openChangePasswordDialog() {
        const data = {
            name: 'Password change required',
            message: 'You are required to reset your password.'
        };
        const dialogRef = this.dialog.open(NgxMatAuthErrorDialogComponent, {
            data: data,
            disableClose: true,
            restoreFocus: false
        });
        await firstValueFrom(dialogRef.afterClosed());
    }
    isRequirePasswordChangeType(res) {
        return !!res.requirePasswordChange;
    }
    /**
     * Opens a two factor dialog with the given configuration data and returns the code that has been input.
     * @param data - Configuration data for the dialog.
     * @returns The input two factor code or undefined if the dialog was closed with cancel.
     */
    async openInput2FADialog(data) {
        const dialogRef = this.dialog.open(NgxMatAuthTwoFactorDialogComponent, {
            data: data,
            disableClose: true,
            restoreFocus: false
        });
        return firstValueFrom(dialogRef.afterClosed());
    }
    isAuthDataType(value) {
        return !!value.userId;
    }
    /**
     * Logout the current user.
     */
    async logout() {
        if (!this.authData) {
            await this.router.navigateByUrl(this.ROUTE_AFTER_LOGOUT);
            return;
        }
        const refreshTokenValue = this.authData.refreshToken.value;
        this.authData = undefined;
        await firstValueFrom(this.http.post(this.API_LOGOUT_URL, { refreshToken: refreshTokenValue }));
        await this.router.navigateByUrl(this.ROUTE_AFTER_LOGOUT);
    }
    /**
     * Refreshes the token.
     */
    async refreshToken() {
        if (!this.authData) {
            return;
        }
        if (this.isRefreshing) {
            await firstValueFrom(this.isRefreshingSubject.asObservable().pipe(filter(v => !v)));
            return;
        }
        this.isRefreshingSubject.next(true);
        try {
            this.authData = await firstValueFrom(this.http.post(this.API_REFRESH_TOKEN_URL, { refreshToken: this.authData.refreshToken.value }));
            this.isRefreshingSubject.next(false);
        }
        catch (error) {
            this.isRefreshingSubject.next(false);
            await this.logout();
            throw error;
        }
    }
    /**
     * Requests a new password from the server.
     * Should sent a reset-link to the given email with a one time short lived (~5 minutes) token.
     * @param email - The email of the user that wants to reset his password.
     */
    async requestResetPassword(email) {
        await firstValueFrom(this.http.post(this.API_REQUEST_RESET_PASSWORD_URL, { email: email }));
        this.zone.run(() => {
            this.snackbar.open(this.REQUEST_RESET_PASSWORD_SNACK_BAR_MESSAGE, undefined, { duration: 5000 });
        });
    }
    /**
     * Confirms the reset of the password.
     * @param newPassword - The new password.
     * @param resetToken - The token from the email. Needed to authorize the password reset.
     */
    async confirmResetPassword(newPassword, resetToken) {
        await firstValueFrom(this.http.post(this.API_CONFIRM_RESET_PASSWORD_URL, {
            password: newPassword,
            resetToken: resetToken
        }));
        this.zone.run(() => {
            this.snackbar.open(this.CONFIRM_RESET_PASSWORD_SNACK_BAR_MESSAGE, undefined, { duration: 5000 });
        });
    }
    /**
     * Checks if the given reset token is valid.
     * @param resetToken - The token from the email. Needed to authorize the password reset.
     * @returns Whether or not the given token is valid.
     */
    async isResetTokenValid(resetToken) {
        const res = await firstValueFrom(this.http.post(this.API_VERIFY_RESET_PASSWORD_TOKEN_URL, { value: resetToken }));
        return res.isValid;
    }
    /**
     * Checks whether or not the currently logged in user has one of the provided roles.
     * @param allowedRolesValues - All roles that are allowed to do a certain thing.
     * @returns Whether or not the user has one of the provided allowed roles.
     */
    hasRole(allowedRolesValues) {
        if (!this.authData) {
            return false;
        }
        return !!allowedRolesValues.find(rv => this.authData?.roles.map(r => r.value).includes(rv));
    }
    /**
     * Generates a qr code url to setup 2fa in eg. Google Authenticator.
     * @returns The response with the qr code url.
     */
    async turnOn2FA() {
        return firstValueFrom(this.http.post(this.API_TURN_ON_TWO_FACTOR_URL, undefined));
    }
    /**
     * Opens the dialog to turn on 2fa. The dialog displays a qr code and an input to confirm with a two factor code.
     * @param data - Configuration data for the dialog.
     */
    openTurnOn2FADialog(data) {
        this.dialog.open(NgxMatAuthSetupTwoFactorDialogComponent, {
            data: data,
            disableClose: true,
            restoreFocus: false
        });
    }
    /**
     * Confirms turning on two factor authentication.
     * Sends the provided two factor code to the configured endpoint.
     * @param twoFactorCode - The two factor code that the user generated using eg. Google Authenticator.
     */
    async confirmTurnOn2FA(twoFactorCode) {
        await firstValueFrom(this.http.post(this.API_CONFIRM_TURN_ON_TWO_FACTOR_URL, undefined, { headers: { [this.TWO_FACTOR_HEADER]: twoFactorCode } }));
        this.authData = {
            ...this.authData,
            twoFactorEnabled: true
        };
    }
    /**
     * Turns off two factor authentication for the current user.
     */
    async turnOff2FA() {
        await firstValueFrom(this.http.post(this.API_TURN_OFF_TWO_FACTOR_URL, undefined));
        if (this.authData) {
            this.authData = {
                ...this.authData,
                twoFactorEnabled: false
            };
        }
    }
    /**
     * Registers a new biometric credential for the currently logged in user.
     */
    async registerBiometricCredential() {
        if (!this.authData) {
            // eslint-disable-next-line no-console
            console.error('Registering new biometric credentials is only possible when already logged in');
            return;
        }
        if (!WebauthnUtilities.browserSupportsWebAuthn()) {
            // eslint-disable-next-line no-console
            console.error('The current browser does not support webauthn.');
            return;
        }
        const options = await firstValueFrom(this.http.post(this.API_REGISTER_BIOMETRIC_CREDENTIAL, undefined));
        try {
            const registrationResponse = await WebauthnUtilities.startRegistration(options);
            const confirmRegistrationResponse = await firstValueFrom(this.http.post(`${this.API_CONFIRM_REGISTER_BIOMETRIC_CREDENTIAL}/${options.challenge}`, registrationResponse));
            if (!confirmRegistrationResponse.verified) {
                // TODO: How should this be handled?
                throw new Error('Could not register a biometric credential');
            }
            this.authData = {
                ...this.authData,
                biometricCredentials: confirmRegistrationResponse.biometricCredentials
            };
        }
        catch (error) {
            await firstValueFrom(this.http.delete(`${this.API_CANCEL_REGISTER_BIOMETRIC_CREDENTIAL}/${options.challenge}`));
            throw error;
        }
    }
    /**
     * Tries to login with biometric authentication.
     */
    async loginWithBiometricAuthentication() {
        if (!this.biometricCredentials.length) {
            return;
        }
        const options = await firstValueFrom(this.http.get(`${this.API_GENERATE_BIOMETRIC_AUTHENTICATION_OPTIONS}/${this.biometricCredentials[0].baseUserId}`));
        const authenticationResponse = await WebauthnUtilities.startAuthentication(options);
        await this.login(authenticationResponse);
    }
};
JwtAuthService = __decorate([
    __param(5, Inject(PLATFORM_ID))
], JwtAuthService);

/**
 * Provider for the default getValidationErrorMessage.
 */
const NGX_GET_VALIDATION_ERROR_MESSAGE = new InjectionToken('Provider for the default getValidationErrorMessage.', {
    providedIn: 'root',
    factory: () => defaultGetValidationErrorMessage
});
/**
 * Generates a default error message for most validation errors.
 * @param model - The ngModel to get the error from.
 * @returns The Validation Error Message to display.
 */
function defaultGetValidationErrorMessage(model) {
    if (model.hasError('matDatepickerParse')) {
        return 'not a valid date';
    }
    else if (model.hasError('email')) {
        return 'not a valid email';
    }
    else if (model.hasError('minlength')) {
        // eslint-disable-next-line typescript/no-unsafe-member-access
        return `needs to be at least ${model.getError('minlength').requiredLength} characters long`;
    }
    else if (model.hasError('min')) {
        // eslint-disable-next-line typescript/no-unsafe-member-access
        return `needs to be equal or bigger than ${model.getError('min').min}`;
    }
    else if (model.hasError('max')) {
        // eslint-disable-next-line typescript/no-unsafe-member-access
        return `needs to be equal or smaller than ${model.getError('max').max}`;
    }
    else if (model.hasError('required')) {
        return 'required';
    }
    // eslint-disable-next-line typescript/no-unsafe-member-access
    else if (model.hasError('pattern') && model.getError('pattern').requiredPattern === '^true$') {
        return 'needs to be selected';
    }
    else {
        return 'invalid input';
    }
}

/**
 * The interface for the confirm reset password functionality.
 *
 * !!!
 * Also checks if the provided reset token is valid.
 * This tries to get the reset token from theActivatedRoute.params['token'].
 * You have to make sure that your reset password link and the routing makes that possible.
 * !!!
 */
class NgxMatAuthConfirmResetPasswordComponent {
    authService;
    defaultGetValidationErrorMessage;
    router;
    route;
    zone;
    dialog;
    /**
     * (optional) A custom function to generate the error-message for invalid inputs.
     */
    getValidationErrorMessage;
    /**
     * The title of the confirm reset password box.
     * @default 'New Password'
     */
    confirmResetPasswordTitle;
    /**
     * The label for the password input.
     * @default 'Password'
     */
    passwordInputLabel;
    /**
     * The minimum length for the password input.
     * @default null // no minimum length
     */
    minLength;
    /**
     * The label for the change password button.
     * @default 'Change Password'
     */
    changePasswordButtonLabel;
    /**
     * A custom label for the cancel button.
     * @default 'Cancel'
     */
    cancelButtonLabel;
    /**
     * The route to which the user gets redirected when he clicks on the cancel button.
     * @default routeAfterReset
     */
    routeForCancel;
    /**
     * The route to which the user gets redirected after the password has been changed successfully.
     * @default '/login'
     */
    routeAfterReset;
    /**
     * The route to which the user gets redirected if the reset token is not correct.
     * @default '/'
     */
    routeIfResetTokenInvalid;
    /**
     * The error data to display in an dialog when the provided reset token doesn't exist or is invalid.
     * @default
     *{
     * name: 'Error',
     * message: '<p>The provided link is no longer active.</p><p>Please check if the url is correct or request a new link.</p>'
     *}
     */
    invalidResetTokenErrorData;
    /**
     * The password input by the user.
     */
    password;
    /**
     * Whether or not the password input is hidden.
     */
    hide = true;
    /**
     * Whether or not the confirm password input is hidden.
     */
    hideConfirm = true;
    resetToken;
    defaultInvalidResetTokenErrorData = {
        name: 'Error',
        message: '<p>The provided link is no longer active.</p><p>Please check if the url is correct or request a new link.</p>'
    };
    constructor(authService, defaultGetValidationErrorMessage, router, route, zone, dialog) {
        this.authService = authService;
        this.defaultGetValidationErrorMessage = defaultGetValidationErrorMessage;
        this.router = router;
        this.route = route;
        this.zone = zone;
        this.dialog = dialog;
    }
    ngOnInit() {
        this.initDefaultValues();
        // eslint-disable-next-line promise/prefer-await-to-then
        void firstValueFrom(this.route.params).then(async (params) => {
            this.resetToken = params['token'];
            if (!this.resetToken
                || !await this.authService.isResetTokenValid(this.resetToken)) {
                await this.router.navigateByUrl(this.routeIfResetTokenInvalid);
                this.zone.run(() => {
                    this.dialog.open(NgxMatAuthErrorDialogComponent, {
                        data: this.invalidResetTokenErrorData,
                        autoFocus: false,
                        restoreFocus: false
                    });
                });
            }
        });
    }
    initDefaultValues() {
        this.getValidationErrorMessage = this.getValidationErrorMessage ?? this.defaultGetValidationErrorMessage;
        this.confirmResetPasswordTitle = this.confirmResetPasswordTitle ?? 'New Password';
        this.passwordInputLabel = this.passwordInputLabel ?? 'Password';
        // eslint-disable-next-line unicorn/no-null
        this.minLength = this.minLength ?? null;
        this.changePasswordButtonLabel = this.changePasswordButtonLabel ?? 'Change Password';
        this.cancelButtonLabel = this.cancelButtonLabel ?? 'Cancel';
        this.routeAfterReset = this.routeAfterReset ?? '/login';
        this.routeIfResetTokenInvalid = this.routeIfResetTokenInvalid ?? '/';
        this.routeForCancel = this.routeForCancel ?? this.routeAfterReset;
        this.invalidResetTokenErrorData = this.invalidResetTokenErrorData ?? this.defaultInvalidResetTokenErrorData;
    }
    /**
     * Cancels the password reset.
     */
    async cancel() {
        await this.router.navigateByUrl(this.routeForCancel);
    }
    /**
     * Changes the password.
     * @param form - The form. Is passed to clear it without triggering input validation errors.
     */
    async onSubmit(form) {
        if (!this.password || !this.resetToken) {
            return;
        }
        try {
            await this.authService.confirmResetPassword(this.password, this.resetToken);
            form.resetForm();
            await this.router.navigateByUrl(this.routeAfterReset);
        }
        catch {
            form.resetForm();
            await this.router.navigateByUrl(this.routeAfterReset);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthConfirmResetPasswordComponent, deps: [{ token: NGX_AUTH_SERVICE }, { token: NGX_GET_VALIDATION_ERROR_MESSAGE }, { token: i1$1.Router }, { token: i1$1.ActivatedRoute }, { token: i0.NgZone }, { token: i1.MatDialog }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: NgxMatAuthConfirmResetPasswordComponent, isStandalone: true, selector: "ngx-mat-auth-confirm-reset-password", inputs: { getValidationErrorMessage: "getValidationErrorMessage", confirmResetPasswordTitle: "confirmResetPasswordTitle", passwordInputLabel: "passwordInputLabel", minLength: "minLength", changePasswordButtonLabel: "changePasswordButtonLabel", cancelButtonLabel: "cancelButtonLabel", routeForCancel: "routeForCancel", routeAfterReset: "routeAfterReset", routeIfResetTokenInvalid: "routeIfResetTokenInvalid", invalidResetTokenErrorData: "invalidResetTokenErrorData" }, ngImport: i0, template: "<div class=\"mat-elevation-z8 confirm-reset-password-box\">\n    <h1>{{confirmResetPasswordTitle}}</h1>\n    <form #formControl=\"ngForm\" (ngSubmit)=\"onSubmit(formControl)\">\n        \n        <mat-form-field>\n            <mat-label>{{passwordInputLabel}}</mat-label>\n            <input\n                #pw=\"ngModel\"\n                matInput\n                name=\"password\"\n                required\n                [type]=\"hide ? 'password' : 'text'\"\n                [minlength]=\"minLength\"\n                [(ngModel)]=\"password\">\n            <button type=\"button\" mat-icon-button matSuffix (click)=\"hide = !hide\">\n                <i class=\"fas\" [class.fa-eye-slash]=\"hide\" [class.fa-eye]=\"!hide\"></i>\n            </button>\n            <!-- eslint-disable-next-line angular/no-call-expression -->\n            <mat-error>{{getValidationErrorMessage(pw)}}</mat-error>\n        </mat-form-field>\n\n        <br>\n        <div class=\"buttons-row\">\n            <button mat-raised-button type=\"submit\">\n                {{changePasswordButtonLabel}}\n            </button>\n            <button mat-raised-button type=\"button\" (click)=\"cancel()\">\n                {{cancelButtonLabel}}\n            </button>\n        </div>\n    </form>\n</div>", styles: [".confirm-reset-password-box{padding:30px;border-radius:5px}h1{text-align:center;margin-bottom:8px}mat-form-field{width:100%}.buttons-row{margin-top:5px;display:inline-grid;grid-template-columns:1fr 1fr;grid-gap:10px}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2$1.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i2$1.MinLengthValidator, selector: "[minlength][formControlName],[minlength][formControl],[minlength][ngModel]", inputs: ["minlength"] }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2$1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i4.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "component", type: i3.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i3.MatLabel, selector: "mat-label" }, { kind: "directive", type: i3.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i3.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "component", type: i2.MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthConfirmResetPasswordComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-auth-confirm-reset-password', standalone: true, imports: [
                        NgIf,
                        FormsModule,
                        MatInputModule,
                        MatFormFieldModule,
                        MatButtonModule,
                        NgxMatAuthErrorDialogComponent
                    ], template: "<div class=\"mat-elevation-z8 confirm-reset-password-box\">\n    <h1>{{confirmResetPasswordTitle}}</h1>\n    <form #formControl=\"ngForm\" (ngSubmit)=\"onSubmit(formControl)\">\n        \n        <mat-form-field>\n            <mat-label>{{passwordInputLabel}}</mat-label>\n            <input\n                #pw=\"ngModel\"\n                matInput\n                name=\"password\"\n                required\n                [type]=\"hide ? 'password' : 'text'\"\n                [minlength]=\"minLength\"\n                [(ngModel)]=\"password\">\n            <button type=\"button\" mat-icon-button matSuffix (click)=\"hide = !hide\">\n                <i class=\"fas\" [class.fa-eye-slash]=\"hide\" [class.fa-eye]=\"!hide\"></i>\n            </button>\n            <!-- eslint-disable-next-line angular/no-call-expression -->\n            <mat-error>{{getValidationErrorMessage(pw)}}</mat-error>\n        </mat-form-field>\n\n        <br>\n        <div class=\"buttons-row\">\n            <button mat-raised-button type=\"submit\">\n                {{changePasswordButtonLabel}}\n            </button>\n            <button mat-raised-button type=\"button\" (click)=\"cancel()\">\n                {{cancelButtonLabel}}\n            </button>\n        </div>\n    </form>\n</div>", styles: [".confirm-reset-password-box{padding:30px;border-radius:5px}h1{text-align:center;margin-bottom:8px}mat-form-field{width:100%}.buttons-row{margin-top:5px;display:inline-grid;grid-template-columns:1fr 1fr;grid-gap:10px}\n"] }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_GET_VALIDATION_ERROR_MESSAGE]
                }] }, { type: i1$1.Router }, { type: i1$1.ActivatedRoute }, { type: i0.NgZone }, { type: i1.MatDialog }], propDecorators: { getValidationErrorMessage: [{
                type: Input
            }], confirmResetPasswordTitle: [{
                type: Input
            }], passwordInputLabel: [{
                type: Input
            }], minLength: [{
                type: Input
            }], changePasswordButtonLabel: [{
                type: Input
            }], cancelButtonLabel: [{
                type: Input
            }], routeForCancel: [{
                type: Input
            }], routeAfterReset: [{
                type: Input
            }], routeIfResetTokenInvalid: [{
                type: Input
            }], invalidResetTokenErrorData: [{
                type: Input
            }] } });

/**
 * A simple login box.
 */
class NgxMatAuthLoginComponent {
    authService;
    defaultGetValidationErrorMessage;
    router;
    /**
     * (optional) A custom function to generate the error-message for invalid inputs.
     */
    getValidationErrorMessage;
    /**
     * A custom title of the login box.
     * @default 'Login'
     */
    loginTitle = 'Login';
    /**
     * A custom label for the email input.
     * @default 'Email'
     */
    emailInputLabel = 'Email';
    /**
     * A custom label for the password input.
     * @default 'Password'
     */
    passwordInputLabel = 'Password';
    /**
     * A custom label for the login button.
     * @default 'Login'
     */
    loginButtonLabel = 'Login';
    /**
     * Data for the forgot password link.
     * @default {
     * displayName: 'Forgot your password?',
     * route: '/reset-password'
     * }
     */
    forgotPasswordLinkData;
    /**
     * The route to which the user gets redirected after he logs in successful.
     * @default '/'
     */
    routeAfterLogin = '/';
    /**
     * Whether or not the user should be prompted for biometric login if the option is available.
     * @default true
     */
    automaticallyPromptForBiometricLogin = true;
    /**
     * The password input by the user.
     */
    password;
    /**
     * The email input by the user.
     */
    email;
    /**
     * Whether or not the password input is hidden.
     */
    hide = true;
    constructor(authService, defaultGetValidationErrorMessage, router) {
        this.authService = authService;
        this.defaultGetValidationErrorMessage = defaultGetValidationErrorMessage;
        this.router = router;
    }
    ngOnInit() {
        this.getValidationErrorMessage = this.getValidationErrorMessage ?? this.defaultGetValidationErrorMessage;
        this.forgotPasswordLinkData = this.forgotPasswordLinkData ?? {
            displayName: 'Forgot your password?',
            route: this.authService.REQUEST_RESET_PASSWORD_ROUTE
        };
        if (this.automaticallyPromptForBiometricLogin && !this.authService.authData && this.authService.biometricCredentials.length) {
            void this.authService.loginWithBiometricAuthentication();
        }
    }
    /**
     * The method that gets called when the user tries to login.
     * @param form - The login form. Is passed to clear it without triggering input validation errors.
     */
    async onSubmit(form) {
        if (!this.email || !this.password) {
            return;
        }
        try {
            await this.authService.login({
                email: this.email,
                password: this.password
            });
            form.resetForm();
            await this.router.navigateByUrl(this.routeAfterLogin);
        }
        catch (error) {
            form.resetForm();
            throw error;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthLoginComponent, deps: [{ token: NGX_AUTH_SERVICE }, { token: NGX_GET_VALIDATION_ERROR_MESSAGE }, { token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.13", type: NgxMatAuthLoginComponent, isStandalone: true, selector: "ngx-mat-auth-login", inputs: { getValidationErrorMessage: "getValidationErrorMessage", loginTitle: "loginTitle", emailInputLabel: "emailInputLabel", passwordInputLabel: "passwordInputLabel", loginButtonLabel: "loginButtonLabel", forgotPasswordLinkData: "forgotPasswordLinkData", routeAfterLogin: "routeAfterLogin", automaticallyPromptForBiometricLogin: "automaticallyPromptForBiometricLogin" }, ngImport: i0, template: "<!-- eslint-disable angular/no-call-expression -->\n<div class=\"mat-elevation-z8 login-box\">\n    <i class=\"title-icon fas fa-circle-user\"></i>\n    <h1>{{loginTitle}}</h1>\n\n    <form #formControl=\"ngForm\" (ngSubmit)=\"onSubmit(formControl)\">\n        <mat-form-field>\n            <mat-label>{{emailInputLabel}}</mat-label>\n            <input #mail=\"ngModel\" matInput name=\"email\" required email [(ngModel)]=\"email\">\n            <mat-error>{{getValidationErrorMessage(mail)}}</mat-error>\n        </mat-form-field>\n        <br>\n        <mat-form-field>\n            <mat-label>{{passwordInputLabel}}</mat-label>\n            <input\n                #pw=\"ngModel\"\n                matInput\n                name=\"password\"\n                required\n                [type]=\"hide ? 'password' : 'text'\"\n                [(ngModel)]=\"password\">\n            <button class=\"hide-password\" type=\"button\" mat-icon-button matSuffix (click)=\"$event.stopPropagation(); hide = !hide\">\n                <i class=\"fas\" [class.fa-eye-slash]=\"hide\" [class.fa-eye]=\"!hide\"></i>\n            </button>\n            <mat-error>{{getValidationErrorMessage(pw)}}</mat-error>\n        </mat-form-field>\n\n        <br>\n\n        <button type=\"submit\" class=\"login-button\" mat-raised-button [disabled]=\"formControl.invalid\">\n            {{loginButtonLabel}}\n        </button>\n        <br>\n        <div class=\"forgot-password-link-container\">\n            <a [routerLink]=\"forgotPasswordLinkData.route\">{{forgotPasswordLinkData.displayName}}</a>\n        </div>\n    </form>\n</div>", styles: [".login-box{padding:30px;border-radius:5px}.login-box .title-icon{width:100%;text-align:center;font-size:50px;margin-bottom:5px}.login-box h1{text-align:center;margin-bottom:8px}.login-box mat-form-field,.login-box button{width:100%}.login-box .hide-password{width:48px;height:48px;display:flex;align-items:center;justify-content:center}.login-box .login-button{margin-top:10px;margin-bottom:10px}.login-box .forgot-password-link-container{text-align:center}.login-box a{text-decoration:none}.login-box a:hover{filter:brightness(.7)}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2$1.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i2$1.EmailValidator, selector: "[email][formControlName],[email][formControl],[email][ngModel]", inputs: ["email"] }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2$1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "component", type: i3.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i3.MatLabel, selector: "mat-label" }, { kind: "directive", type: i3.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "directive", type: i3.MatSuffix, selector: "[matSuffix], [matIconSuffix], [matTextSuffix]", inputs: ["matTextSuffix"] }, { kind: "ngmodule", type: RouterModule }, { kind: "directive", type: i1$1.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i4.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }, { kind: "component", type: i2.MatIconButton, selector: "button[mat-icon-button]", exportAs: ["matButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthLoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-auth-login', standalone: true, imports: [
                        NgIf,
                        FormsModule,
                        MatFormFieldModule,
                        RouterModule,
                        MatInputModule,
                        MatButtonModule
                    ], template: "<!-- eslint-disable angular/no-call-expression -->\n<div class=\"mat-elevation-z8 login-box\">\n    <i class=\"title-icon fas fa-circle-user\"></i>\n    <h1>{{loginTitle}}</h1>\n\n    <form #formControl=\"ngForm\" (ngSubmit)=\"onSubmit(formControl)\">\n        <mat-form-field>\n            <mat-label>{{emailInputLabel}}</mat-label>\n            <input #mail=\"ngModel\" matInput name=\"email\" required email [(ngModel)]=\"email\">\n            <mat-error>{{getValidationErrorMessage(mail)}}</mat-error>\n        </mat-form-field>\n        <br>\n        <mat-form-field>\n            <mat-label>{{passwordInputLabel}}</mat-label>\n            <input\n                #pw=\"ngModel\"\n                matInput\n                name=\"password\"\n                required\n                [type]=\"hide ? 'password' : 'text'\"\n                [(ngModel)]=\"password\">\n            <button class=\"hide-password\" type=\"button\" mat-icon-button matSuffix (click)=\"$event.stopPropagation(); hide = !hide\">\n                <i class=\"fas\" [class.fa-eye-slash]=\"hide\" [class.fa-eye]=\"!hide\"></i>\n            </button>\n            <mat-error>{{getValidationErrorMessage(pw)}}</mat-error>\n        </mat-form-field>\n\n        <br>\n\n        <button type=\"submit\" class=\"login-button\" mat-raised-button [disabled]=\"formControl.invalid\">\n            {{loginButtonLabel}}\n        </button>\n        <br>\n        <div class=\"forgot-password-link-container\">\n            <a [routerLink]=\"forgotPasswordLinkData.route\">{{forgotPasswordLinkData.displayName}}</a>\n        </div>\n    </form>\n</div>", styles: [".login-box{padding:30px;border-radius:5px}.login-box .title-icon{width:100%;text-align:center;font-size:50px;margin-bottom:5px}.login-box h1{text-align:center;margin-bottom:8px}.login-box mat-form-field,.login-box button{width:100%}.login-box .hide-password{width:48px;height:48px;display:flex;align-items:center;justify-content:center}.login-box .login-button{margin-top:10px;margin-bottom:10px}.login-box .forgot-password-link-container{text-align:center}.login-box a{text-decoration:none}.login-box a:hover{filter:brightness(.7)}\n"] }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_GET_VALIDATION_ERROR_MESSAGE]
                }] }, { type: i1$1.Router }], propDecorators: { getValidationErrorMessage: [{
                type: Input
            }], loginTitle: [{
                type: Input
            }], emailInputLabel: [{
                type: Input
            }], passwordInputLabel: [{
                type: Input
            }], loginButtonLabel: [{
                type: Input
            }], forgotPasswordLinkData: [{
                type: Input
            }], routeAfterLogin: [{
                type: Input
            }], automaticallyPromptForBiometricLogin: [{
                type: Input
            }] } });

/**
 * A simple request reset password box.
 */
class NgxMatAuthRequestResetPasswordComponent {
    authService;
    defaultGetValidationErrorMessage;
    router;
    /**
     * (optional) A custom function to generate the error-message for invalid inputs.
     */
    getValidationErrorMessage;
    /**
     * The title of the request reset password box.
     * @default 'Forgot Password'
     */
    requestResetPasswordTitle;
    /**
     * A custom label for the email input.
     * @default 'Email'
     */
    emailInputLabel;
    /**
     * A custom label for the send email button.
     * @default 'Send Email'
     */
    sendEmailButtonLabel;
    /**
     * A custom label for the cancel button.
     * @default 'Cancel'
     */
    cancelButtonLabel;
    /**
     * The route to navigate to after the user successfully requests the reset of his password.
     * @default '/login'
     */
    routeAfterRequest;
    /**
     * The email for the account which password should be reset.
     */
    email;
    constructor(authService, defaultGetValidationErrorMessage, router) {
        this.authService = authService;
        this.defaultGetValidationErrorMessage = defaultGetValidationErrorMessage;
        this.router = router;
    }
    ngOnInit() {
        this.requestResetPasswordTitle = this.requestResetPasswordTitle ?? 'Forgot Password';
        this.getValidationErrorMessage = this.getValidationErrorMessage ?? this.defaultGetValidationErrorMessage;
        this.emailInputLabel = this.emailInputLabel ?? 'Email';
        this.sendEmailButtonLabel = this.sendEmailButtonLabel ?? 'Send Email';
        this.cancelButtonLabel = this.cancelButtonLabel ?? 'Cancel';
        this.routeAfterRequest = this.routeAfterRequest ?? '/login';
    }
    /**
     * Cancels the password reset.
     */
    async cancel() {
        await this.router.navigateByUrl(this.routeAfterRequest);
    }
    /**
     * Requests the reset of the password for the user with the given email.
     * @param form - The login form. Is passed to clear it without triggering input validation errors.
     */
    async onSubmit(form) {
        if (!this.email) {
            return;
        }
        try {
            await this.authService.requestResetPassword(this.email);
            form.resetForm();
            await this.router.navigateByUrl(this.routeAfterRequest);
        }
        catch (error) {
            form.resetForm();
            throw error;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthRequestResetPasswordComponent, deps: [{ token: NGX_AUTH_SERVICE }, { token: NGX_GET_VALIDATION_ERROR_MESSAGE }, { token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: NgxMatAuthRequestResetPasswordComponent, isStandalone: true, selector: "ngx-mat-auth-request-reset-password", inputs: { getValidationErrorMessage: "getValidationErrorMessage", requestResetPasswordTitle: "requestResetPasswordTitle", emailInputLabel: "emailInputLabel", sendEmailButtonLabel: "sendEmailButtonLabel", cancelButtonLabel: "cancelButtonLabel", routeAfterRequest: "routeAfterRequest" }, ngImport: i0, template: "<div class=\"mat-elevation-z8 request-reset-password-box\">\n    <h1>{{requestResetPasswordTitle}}</h1>\n    <form #formControl=\"ngForm\" (ngSubmit)=\"onSubmit(formControl)\">\n        <mat-form-field>\n            <mat-label>{{emailInputLabel}}</mat-label>\n            <input #mail=\"ngModel\" matInput type=\"email\" name=\"email\" required email [(ngModel)]=\"email\">\n            @if (mail.errors) {\n                <!-- eslint-disable-next-line angular/no-call-expression -->\n                <mat-error>{{getValidationErrorMessage(mail)}}</mat-error>\n            }\n        </mat-form-field>\n        <br>\n        <div class=\"buttons-row\">\n            <button mat-raised-button type=\"submit\" [disabled]=\"formControl.invalid\">\n                {{sendEmailButtonLabel}}\n            </button>\n            <button mat-raised-button type=\"button\" (click)=\"cancel()\">\n                {{cancelButtonLabel}}\n            </button>\n        </div>\n    </form>\n</div>", styles: [".request-reset-password-box{padding:30px;border-radius:5px}h1{text-align:center;margin-bottom:8px}mat-form-field{width:100%}.buttons-row{margin-top:5px;display:inline-grid;grid-template-columns:1fr 1fr;grid-gap:10px}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i2$1.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i2$1.EmailValidator, selector: "[email][formControlName],[email][formControl],[email][ngModel]", inputs: ["email"] }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i2$1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "component", type: i3.MatFormField, selector: "mat-form-field", inputs: ["hideRequiredMarker", "color", "floatLabel", "appearance", "subscriptSizing", "hintLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i3.MatLabel, selector: "mat-label" }, { kind: "directive", type: i3.MatError, selector: "mat-error, [matError]", inputs: ["id"] }, { kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i4.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "ngmodule", type: MatButtonModule }, { kind: "component", type: i2.MatButton, selector: "    button[mat-button], button[mat-raised-button], button[mat-flat-button],    button[mat-stroked-button]  ", exportAs: ["matButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: NgxMatAuthRequestResetPasswordComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-mat-auth-request-reset-password', standalone: true, imports: [
                        NgIf,
                        FormsModule,
                        MatFormFieldModule,
                        MatInputModule,
                        MatButtonModule
                    ], template: "<div class=\"mat-elevation-z8 request-reset-password-box\">\n    <h1>{{requestResetPasswordTitle}}</h1>\n    <form #formControl=\"ngForm\" (ngSubmit)=\"onSubmit(formControl)\">\n        <mat-form-field>\n            <mat-label>{{emailInputLabel}}</mat-label>\n            <input #mail=\"ngModel\" matInput type=\"email\" name=\"email\" required email [(ngModel)]=\"email\">\n            @if (mail.errors) {\n                <!-- eslint-disable-next-line angular/no-call-expression -->\n                <mat-error>{{getValidationErrorMessage(mail)}}</mat-error>\n            }\n        </mat-form-field>\n        <br>\n        <div class=\"buttons-row\">\n            <button mat-raised-button type=\"submit\" [disabled]=\"formControl.invalid\">\n                {{sendEmailButtonLabel}}\n            </button>\n            <button mat-raised-button type=\"button\" (click)=\"cancel()\">\n                {{cancelButtonLabel}}\n            </button>\n        </div>\n    </form>\n</div>", styles: [".request-reset-password-box{padding:30px;border-radius:5px}h1{text-align:center;margin-bottom:8px}mat-form-field{width:100%}.buttons-row{margin-top:5px;display:inline-grid;grid-template-columns:1fr 1fr;grid-gap:10px}\n"] }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_GET_VALIDATION_ERROR_MESSAGE]
                }] }, { type: i1$1.Router }], propDecorators: { getValidationErrorMessage: [{
                type: Input
            }], requestResetPasswordTitle: [{
                type: Input
            }], emailInputLabel: [{
                type: Input
            }], sendEmailButtonLabel: [{
                type: Input
            }], cancelButtonLabel: [{
                type: Input
            }], routeAfterRequest: [{
                type: Input
            }] } });

/**
 * Injection Token for the auth service.
 */
const NGX_GUARD_CONFIG = new InjectionToken('Provider for guard configuration.', {
    providedIn: 'root',
    factory: () => {
        return {};
    }
});

// eslint-disable-next-line jsdoc/require-param
/**
 * Checks if the currently logged in user has the role required for a specific route.
 */
const JwtBelongsToGuard = async (route, state) => {
    const router = inject(Router);
    // eslint-disable-next-line typescript/no-explicit-any
    const authService = inject(NGX_AUTH_SERVICE);
    const config = inject(NGX_GUARD_CONFIG);
    const routeAfterLogout = config.belongsToGuard?.routeAfterLogout ?? authService.ROUTE_AFTER_LOGOUT;
    const routeAfterRedirect = config.belongsToGuard?.routeAfterRedirect ?? '/';
    const userShouldBeLoggedOut = config.belongsToGuard?.userShouldBeLoggedOut ?? (() => true);
    const getBelongsToForRoute = config.belongsToGuard?.getBelongsToForRoute ?? defaultGetBelongsToForRoute;
    if (await getBelongsToForRoute(route, state)) {
        return true;
    }
    if (await userShouldBeLoggedOut(route, state)) {
        await authService.logout();
        await router.navigateByUrl(routeAfterLogout);
    }
    else {
        await router.navigateByUrl(routeAfterRedirect);
    }
    return false;
};
// eslint-disable-next-line jsdoc/require-jsdoc, unusedImports/no-unused-vars
function defaultGetBelongsToForRoute(route, state) {
    throw new Error('If you want to use the JwtBelongsToGuard, the guard configuration needs to be provided on the Injection Token NGX_GUARD_CONFIG.');
}

// eslint-disable-next-line jsdoc/require-param
/**
 * Checks if the user is currently logged in.
 */
const JwtLoggedInGuard = async (route, state) => {
    const router = inject(Router);
    // eslint-disable-next-line typescript/no-explicit-any
    const authService = inject(NGX_AUTH_SERVICE);
    const config = inject(NGX_GUARD_CONFIG);
    const routeAfterLogout = config.loggedInGuard?.routeAfterLogout ?? authService.ROUTE_AFTER_LOGOUT;
    const routeAfterRedirect = config.loggedInGuard?.routeAfterRedirect ?? '/';
    const userShouldBeLoggedOut = config.loggedInGuard?.userShouldBeLoggedOut ?? (() => true);
    if (authService.authData != undefined) {
        return true;
    }
    if (await userShouldBeLoggedOut(route, state)) {
        await authService.logout();
        await router.navigateByUrl(routeAfterLogout);
    }
    else {
        await router.navigateByUrl(routeAfterRedirect);
    }
    return false;
};

// eslint-disable-next-line jsdoc/require-param
/**
 * Checks if the user is currently NOT logged in.
 * This can be useful if you want to disable already logged in user to access the login page etc.
 */
const JwtNotLoggedInGuard = async (route, state) => {
    const router = inject(Router);
    // eslint-disable-next-line typescript/no-explicit-any
    const authService = inject(NGX_AUTH_SERVICE);
    const config = inject(NGX_GUARD_CONFIG);
    const routeAfterLogout = config.notLoggedInGuard?.routeAfterLogout ?? authService.ROUTE_AFTER_LOGOUT;
    const routeAfterRedirect = config.notLoggedInGuard?.routeAfterRedirect ?? '/';
    const userShouldBeLoggedOut = config.notLoggedInGuard?.userShouldBeLoggedOut ?? (() => true);
    if (authService.authData == undefined) {
        return true;
    }
    if (await userShouldBeLoggedOut(route, state)) {
        await authService.logout();
        await router.navigateByUrl(routeAfterLogout);
    }
    else {
        await router.navigateByUrl(routeAfterRedirect);
    }
    return false;
};

// eslint-disable-next-line jsdoc/require-param
/**
 * Checks if the currently logged in user has the role required for a specific route.
 */
const JwtRoleGuard = async (route, state) => {
    const router = inject(Router);
    // eslint-disable-next-line typescript/no-explicit-any
    const authService = inject(NGX_AUTH_SERVICE);
    const config = inject(NGX_GUARD_CONFIG);
    const routeAfterLogout = config.roleGuard?.routeAfterLogout ?? authService.ROUTE_AFTER_LOGOUT;
    const routeAfterRedirect = config.roleGuard?.routeAfterRedirect ?? '/';
    // eslint-disable-next-line typescript/typedef
    const userShouldBeLoggedOut = config.roleGuard?.userShouldBeLoggedOut ?? (() => true);
    // eslint-disable-next-line typescript/typedef
    const getAllowedRoleValuesForRoute = config.roleGuard?.getAllowedRoleValuesForRoute ?? defaultGetAllowedRoleValuesForRoute;
    const allowedRoles = await getAllowedRoleValuesForRoute(route, state);
    const hasRole = authService.hasRole(allowedRoles);
    if (hasRole) {
        return true;
    }
    if (await userShouldBeLoggedOut(route, state)) {
        await authService.logout();
        await router.navigateByUrl(routeAfterLogout);
    }
    else {
        await router.navigateByUrl(routeAfterRedirect);
    }
    return false;
};
// eslint-disable-next-line jsdoc/require-jsdoc
function defaultGetAllowedRoleValuesForRoute(route, 
// eslint-disable-next-line unusedImports/no-unused-vars
state) {
    return route.data['allowedRoles'] ?? [];
}

/**
 * Interceptor that does error handling for http requests.
 */
class HttpErrorInterceptor {
    router;
    authService;
    dialog;
    platformId;
    /**
     * The message to display when the user has no internet connection.
     */
    NO_INTERNET_CONNECTION_ERROR_MESSAGE = 'No Internet Connection.<br>Please try again later.';
    /**
     * The message to display when an error with CORS occurs.
     */
    CORS_ERROR_MESSAGE = 'CORS Error<br>Check your console for more information.';
    /**
     * All error codes for which the user should be logged out.
     */
    logoutStatuses = [
        HttpStatusCode.Unauthorized,
        HttpStatusCode.Forbidden
    ];
    // eslint-disable-next-line jsdoc/require-returns
    /**
     * Any api urls for which the user shouldn't be logged out.
     * Eg. The login page.
     */
    get apiUrlsWithNoLogout() {
        return [
            this.authService.API_TURN_ON_TWO_FACTOR_URL,
            this.authService.API_CONFIRM_TURN_ON_TWO_FACTOR_URL
        ];
    }
    constructor(router, authService, dialog, platformId) {
        this.router = router;
        this.authService = authService;
        this.dialog = dialog;
        this.platformId = platformId;
    }
    /**
     * The main method used by angular to intercept any http-requests with errors.
     * Displays an error message to the user and logs him out if requested.
     * @param request - The http-request that was intercepted.
     * @param next - The next http-handler in angular's chain.
     * @returns An Observable that is used by angular in the intercept chain.
     */
    intercept(request, next) {
        return next.handle(request).pipe(
        // eslint-disable-next-line promise/prefer-await-to-callbacks
        catchError((error) => {
            if (this.userShouldBeLoggedOut(error, request)) {
                void this.authService.logout();
            }
            if (this.errorDialogShouldBeDisplayed(error, request)) {
                const errorData = {
                    name: 'HTTP-Error',
                    message: this.getErrorDataMessage(error)
                };
                this.dialog.open(NgxMatAuthErrorDialogComponent, {
                    data: errorData,
                    autoFocus: false,
                    restoreFocus: false
                });
            }
            return throwError(() => error);
        }));
    }
    /**
     * Checks if the user should be logged out after triggering the provided error.
     * @param error - The http-error that came from the api.
     * @param request - Data about the request that caused the error.
     * @returns Whether or not the current user should be logged out.
     */
    userShouldBeLoggedOut(error, request) {
        if (this.apiUrlsWithNoLogout.find(url => url === request.url)) {
            return false;
        }
        return !!this.logoutStatuses.find(s => s === error.status);
    }
    /**
     * Checks if an dialog for the given error should be displayed to the user.
     * @param error - The http-error that was thrown.
     * @param request - Data about the request that caused the error.
     * @returns Whether or not an dialog should be displayed for the error.
     */
    // eslint-disable-next-line unusedImports/no-unused-vars
    errorDialogShouldBeDisplayed(error, request) {
        return true;
    }
    /**
     * Gets the message from the HttpError.
     * Prefers the most nested one.
     * @param error - The http-error that was thrown.
     * @returns The message of the http-error.
     */
    getErrorDataMessage(error) {
        if (error.error != undefined && typeof error.error === 'object') {
            return this.getErrorDataMessage(error.error);
        }
        if (error.message) {
            return error.message;
        }
        if (this.isCORSError(error)) {
            if (!isPlatformBrowser(this.platformId)) {
                return this.CORS_ERROR_MESSAGE;
            }
            if (!window.navigator.onLine) {
                return this.NO_INTERNET_CONNECTION_ERROR_MESSAGE;
            }
            return this.CORS_ERROR_MESSAGE;
        }
        return JSON.stringify(error);
    }
    /**
     * Checks if the provided error has something to do with CORS.
     * @param error - The error to check.
     * @returns Whether or not the provided error has something to do with CORS.
     */
    isCORSError(error) {
        const stringifiedError = JSON.stringify(error);
        return stringifiedError === JSON.stringify({ isTrusted: true })
            || stringifiedError === JSON.stringify({ isTrusted: false });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HttpErrorInterceptor, deps: [{ token: i1$1.Router }, { token: NGX_AUTH_SERVICE }, { token: i1.MatDialog }, { token: PLATFORM_ID }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HttpErrorInterceptor, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: HttpErrorInterceptor, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1$1.Router }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }, { type: i1.MatDialog }, { type: Object, decorators: [{
                    type: Inject,
                    args: [PLATFORM_ID]
                }] }] });

/**
 * Used to define domains to which an jwt token should be added. This should be used to not send tokens e.g. To third party apis.
 */
const NGX_JWT_INTERCEPTOR_ALLOWED_DOMAINS = new InjectionToken('Used to define domains to which an jwt token should be added. This should be used to not send tokens e.g. to third party apis.', {
    providedIn: 'root',
    factory: () => {
        // eslint-disable-next-line no-console
        console.warn(
        // eslint-disable-next-line stylistic/max-len
        'No allowedDomains have been provided for the token NGX_JWT_INTERCEPTOR_ALLOWED_DOMAINS.\nRight now every http-request adds the jwt token. It is encouraged to provide a value for this to prohibit sending jwt tokens to e.g. third party apis.\nAdd this to your app.module.ts provider array:\n{\n    provide: NGX_JWT_INTERCEPTOR_ALLOWED_DOMAINS,\n    useValue: ["myDomain", "myOtherDomain"]\n}');
    }
});
/**
 * Interceptor that sets the authorization header to the current token on every request.
 * Does nothing when the user isn't logged in.
 */
class JwtInterceptor {
    authService;
    allowedDomains;
    constructor(authService, allowedDomains) {
        this.authService = authService;
        this.allowedDomains = allowedDomains;
        this.allowedDomains = this.allowedDomains?.map(ad => this.getDomainFromUrl(ad));
    }
    /**
     * The main method used by angular to intercept any http-requests and append the jwt.
     * @param request - The http-request that was intercepted.
     * @param next - The next http-handler in angular's chain.
     * @returns An Observable that is used by angular in the intercept chain.
     */
    intercept(request, next) {
        if (!this.authService.authData || this.requestIsToDisallowedDomain(request) || this.requestDoesNotRequireToken(request)) {
            // user is not logged in, therefore the request is just passed
            return next.handle(request);
        }
        if (this.refreshTokenExpired()) {
            // the users refresh token is expired => he is completely logged out, without any chance to automatically refresh the login
            this.authService.authData = undefined;
            return next.handle(request);
        }
        if (this.tokenNeedsToBeRefreshed(request)) {
            // there is a user that is currently logged in but needs refreshing.
            return this.refreshAndHandle(request, next);
        }
        // There is a logged that does not need refreshing.
        request = request.clone({
            setHeaders: {
                authorization: `Bearer ${this.authService.authData.accessToken.value}`
            }
        });
        return next.handle(request);
    }
    /**
     * Check if the intercepted request is one of the special cases where no token is required.
     *
     * By default this is the case for the refresh-token and logout url.
     * @param request - The http-request that was intercepted.
     * @returns Whether or not the intercepted request is one of the special cases where no token is required.
     */
    requestDoesNotRequireToken(request) {
        return request.url === this.authService.API_REFRESH_TOKEN_URL
            || request.url === this.authService.API_LOGOUT_URL;
    }
    /**
     * Refreshes the token synchronous and sends the request afterwards.
     * @param request - The http-request that was intercepted.
     * @param next - The next http-handler in angular's chain.
     * @returns A promise of an unknown HttpEvent. Inside the interceptor you need to call "return from(this.refreshAndHandle(...))".
     */
    refreshAndHandle(request, next) {
        return from(this.authService.refreshToken()).pipe(exhaustMap(() => {
            request = request.clone({
                setHeaders: {
                    authorization: `Bearer ${this.authService.authData?.accessToken.value}`
                }
            });
            return next.handle(request);
        }));
    }
    /**
     * Checks whether or not the token needs to be refreshed.
     * @param request - The request to check.
     * @returns Whether or not the token needs to be refreshed.
     */
    // eslint-disable-next-line unusedImports/no-unused-vars
    tokenNeedsToBeRefreshed(request) {
        const tokenExpirationDate = new Date(this.authService.authData?.accessToken.expirationDate);
        const expirationInMs = tokenExpirationDate.getTime();
        return expirationInMs <= Date.now();
    }
    /**
     * Checks whether or not the refresh token is expired.
     * @returns Whether or not the refresh token is expired.
     * @throws When there is no logged in user.
     */
    refreshTokenExpired() {
        if (!this.authService.authData) {
            // this should actually never be reached,
            // because before this call there is a check for missing auth data.
            throw new Error('There is no currently logged in user.');
        }
        const tokenExpirationDate = new Date(this.authService.authData.refreshToken.expirationDate);
        const expirationInMs = tokenExpirationDate.getTime();
        return expirationInMs <= Date.now();
    }
    /**
     * Checks if the request is to an allowed domain.
     * @param request - The request to check.
     * @returns Whether the request is to an allowed domain or not. Defaults to true if no allowed host names were provided.
     */
    requestIsToDisallowedDomain(request) {
        if (!this.allowedDomains) {
            return false;
        }
        const domain = this.getDomainFromUrl(request.url);
        return !this.allowedDomains.includes(domain);
    }
    /**
     * Gets a normalized domain from an url.
     * Is used for comparing the request url with the allowed domains array.
     * @param url - The url to get the domain from.
     * @returns The domain of the url.
     */
    getDomainFromUrl(url) {
        if (url.startsWith('https://')) {
            url = url.split('https://')[1];
        }
        if (url.startsWith('http://')) {
            url = url.split('http://')[1];
        }
        if (url.startsWith('www.')) {
            url = url.split('www.')[1];
        }
        url = url.split('/')[0];
        return url;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JwtInterceptor, deps: [{ token: NGX_AUTH_SERVICE }, { token: NGX_JWT_INTERCEPTOR_ALLOWED_DOMAINS }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JwtInterceptor, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: JwtInterceptor, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_JWT_INTERCEPTOR_ALLOWED_DOMAINS]
                }] }] });

/**
 * Used to define urls where a two factor code is needed.
 */
const NGX_JWT_INTERCEPTOR_RESTRICTED_URLS = new InjectionToken('Used to define urls where a two factor code is needed.', {
    providedIn: 'root',
    factory: () => []
});
/**
 * Interceptor that prompts the user for a two factor code .
 */
class TwoFactorInterceptor {
    restrictedUrls;
    authService;
    constructor(restrictedUrls, authService) {
        this.restrictedUrls = restrictedUrls;
        this.authService = authService;
    }
    // eslint-disable-next-line jsdoc/require-jsdoc
    intercept(request, next) {
        if (this.authService.authData?.twoFactorEnabled === true && this.restrictedUrls.includes(request.url)) {
            return this.addCodeAndHandle(request, next);
        }
        return next.handle(request);
    }
    /**
     * Prompts the user for a two factor code, adds it to the given request.
     * @param request - The request that got intercepted.
     * @param next - The next http-handler in angular's chain.
     * @returns A promise of the http event stream. Needs to be returned with "from" inside the intercept method.
     */
    addCodeAndHandle(request, next) {
        return from(this.authService.openInput2FADialog()).pipe(exhaustMap(code => {
            if (!code) {
                throw new Error('No two factor code has been provided.');
            }
            request = request.clone({
                setHeaders: {
                    [this.authService.TWO_FACTOR_HEADER]: code
                }
            });
            return next.handle(request);
        }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TwoFactorInterceptor, deps: [{ token: NGX_JWT_INTERCEPTOR_RESTRICTED_URLS }, { token: NGX_AUTH_SERVICE }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TwoFactorInterceptor });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: TwoFactorInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [NGX_JWT_INTERCEPTOR_RESTRICTED_URLS]
                }] }, { type: JwtAuthService, decorators: [{
                    type: Inject,
                    args: [NGX_AUTH_SERVICE]
                }] }] });

/*
 * Public API Surface of ngx-material-auth
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HttpErrorInterceptor, JwtAuthService, JwtBelongsToGuard, JwtInterceptor, JwtLoggedInGuard, JwtNotLoggedInGuard, JwtRoleGuard, NGX_AUTH_SERVICE, NGX_GET_VALIDATION_ERROR_MESSAGE, NGX_GUARD_CONFIG, NGX_JWT_INTERCEPTOR_ALLOWED_DOMAINS, NGX_JWT_INTERCEPTOR_RESTRICTED_URLS, NgxMatAuthConfirmResetPasswordComponent, NgxMatAuthErrorDialogComponent, NgxMatAuthLoginComponent, NgxMatAuthRequestResetPasswordComponent, NgxMatAuthSetupTwoFactorDialogComponent, NgxMatAuthTwoFactorCodeInputComponent, NgxMatAuthTwoFactorDialogComponent, TwoFactorInterceptor, defaultGetValidationErrorMessage };
//# sourceMappingURL=ngx-material-auth.mjs.map
