import { CanActivateFn } from '@angular/router';
import { BooleanFunction } from './boolean-function.type';
/**
 * Configuration for the JwtLoggedInGuard.
 */
export interface JwtLoggedInGuardConfig {
    /**
     * When the user tries to access a route for which he doesn't have the permission and is logged out
     * he gets redirected to this route afterwards.
     * @default The auth service ROUTE_AFTER_LOGOUT, which defaults to '/login'
     */
    routeAfterLogout: string;
    /**
     * When the user tries to access a route for which he doesn't have the permission but is NOT logged out
     * he gets redirected to this route afterwards.
     * @default '/'
     */
    routeAfterRedirect: string;
    /**
     * Defines whether or not the user should be logged out based on the route he tried to access.
     * By default this simply returns true.
     * @param route - The route that the user failed to access.
     * @param state - The router state.
     * @returns Whether or not the user should be logged out.
     */
    userShouldBeLoggedOut: BooleanFunction;
}
/**
 * Checks if the user is currently logged in.
 */
export declare const JwtLoggedInGuard: CanActivateFn;
