import { ActivatedRouteSnapshot, CanActivateFn, RouterStateSnapshot } from '@angular/router';
import { JwtLoggedInGuardConfig } from './jwt-logged-in.guard';
type AllowedRolesFunction<RoleValue extends string> = ((route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => RoleValue[]) | ((route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => Promise<RoleValue[]>);
/**
 * Configuration for the JwtRoleGuard.
 */
export interface JwtRoleGuardConfig<RoleValue extends string> extends JwtLoggedInGuardConfig {
    /**
     * Gets all allowed roles for the provided route.
     *
     * By default this method tries to get these from the routes data property.
     * @see https://angular.io/api/router/Route#data
     * @param route - The route that the user tries to navigate to.
     * @param state - State data of the route.
     * @returns The allowed roles for the provided route as an array.
     */
    getAllowedRoleValuesForRoute: AllowedRolesFunction<RoleValue>;
}
/**
 * Checks if the currently logged in user has the role required for a specific route.
 */
export declare const JwtRoleGuard: CanActivateFn;
export {};
