import { HttpEvent, HttpHandler, HttpInterceptor, HttpRequest } from '@angular/common/http';
import { InjectionToken } from '@angular/core';
import { Observable } from 'rxjs';
import { BaseAuthData } from '../models/base-auth-data.model';
import { BaseRole } from '../models/base-role.model';
import { BaseToken } from '../models/base-token.model';
import { JwtAuthService } from '../services/jwt-auth.service';
import * as i0 from "@angular/core";
/**
 * Used to define urls where a two factor code is needed.
 */
export declare const NGX_JWT_INTERCEPTOR_RESTRICTED_URLS: InjectionToken<string[]>;
/**
 * Interceptor that prompts the user for a two factor code .
 */
export declare class TwoFactorInterceptor implements HttpInterceptor {
    protected readonly restrictedUrls: string[];
    protected readonly authService: JwtAuthService<BaseAuthData<BaseToken, string, BaseRole<string>>, string, BaseRole<string>, BaseToken>;
    constructor(restrictedUrls: string[], authService: JwtAuthService<BaseAuthData<BaseToken, string, BaseRole<string>>, string, BaseRole<string>, BaseToken>);
    intercept(request: HttpRequest<unknown>, next: HttpHandler): Observable<HttpEvent<unknown>>;
    /**
     * Prompts the user for a two factor code, adds it to the given request.
     * @param request - The request that got intercepted.
     * @param next - The next http-handler in angular's chain.
     * @returns A promise of the http event stream. Needs to be returned with "from" inside the intercept method.
     */
    protected addCodeAndHandle(request: HttpRequest<unknown>, next: HttpHandler): Observable<HttpEvent<unknown>>;
    static ɵfac: i0.ɵɵFactoryDeclaration<TwoFactorInterceptor, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TwoFactorInterceptor>;
}
